@@ -45,7 +45,7 @@ MainWidget::MainWidget(const UserProfile& userProfile, QWidget*)
 
 	// timer
 	this->timer = new QTimer(this);
-	this->timer->setInterval(100);
+	this->timer->setInterval(500);
 	connect(this->timer, SIGNAL(timeout()), this, SLOT(timerInterrupt()));
 
 	// time stat
@@ -54,7 +54,7 @@ MainWidget::MainWidget(const UserProfile& userProfile, QWidget*)
 	timeLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 
 	this->timeLCD = new QLCDNumber;
-	this->timeLCD->setNumDigits(4);
+	this->timeLCD->setDigitCount(4);
 
 	// mistake stat
 	QLabel* mistakesLabel = new QLabel();
@@ -65,9 +65,9 @@ MainWidget::MainWidget(const UserProfile& userProfile, QWidget*)
 	mistakesDividerLabel->setText(tr("of"));
 
 	this->mistakesLCD = new QLCDNumber;
-	this->mistakesLCD->setNumDigits(1);
+	this->mistakesLCD->setDigitCount(1);
 	this->maxMistakesLCD = new QLCDNumber;
-	this->maxMistakesLCD->setNumDigits(1);
+	this->maxMistakesLCD->setDigitCount(1);
 
 	// speed stat
 	QLabel* speedLabel = new QLabel();
@@ -75,7 +75,7 @@ MainWidget::MainWidget(const UserProfile& userProfile, QWidget*)
 	speedLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 
 	this->speedLCD = new QLCDNumber;
-	this->speedLCD->setNumDigits(4);
+	this->speedLCD->setDigitCount(4);
 
 	// setting buttons
 	this->startButton = new QPushButton(tr("Start"));
