@@ -28,11 +28,11 @@
 #include <QMap>
 #include <QPushButton>
 
-#include <qwt_plot.h>
-#include <qwt_plot_curve.h>
-#include <qwt_plot_grid.h>
-#include <qwt_text_label.h>
-#include <qwt_scale_engine.h>
+#include <qwt/qwt_plot.h>
+#include <qwt/qwt_plot_curve.h>
+#include <qwt/qwt_plot_grid.h>
+#include <qwt/qwt_text_label.h>
+#include <qwt/qwt_scale_engine.h>
 
 #include "StatsWidget.hpp"
 #include "Setup.hpp"
